@@ -1,9 +1,10 @@
-#!/bin/python3
+"""Demonstrates how to create a basic ARP Daemon"""
+#!/usr/bin/python3
 # Runs basic ARP Daemon
 __author__ = "Matt Baker"
 __credits__ = ["Matt Baker"]
 __license__ = "GPL"
-__version__ = "1.0.5"
+__version__ = "1.0.6"
 __maintainer__ = "Matt Baker"
 __email__ = "mbakervtech@gmail.com"
 __status__ = "Development"
