@@ -1,20 +1,26 @@
+#!/usr/bin/python3
+""" Creates class that listens and responds to Layer 3 IPv6"""
 __author__ = "Matt Baker"
 __credits__ = ["Matt Baker"]
 __license__ = "GPL"
-__version__ = "1.0.5"
+__version__ = "1.0.6"
 __maintainer__ = "Matt Baker"
 __email__ = "mbakervtech@gmail.com"
 __status__ = "Development"
 from ipaddress import ip_address, AddressValueError
 from sendit.protocols.ipv6 import IPv6
 class IPv6_Listener():
-
+    """
+    :param ips: list of IPs to listen for
+    :type ips: List of Strings
+    :param listeners: dictionary mapping list of upper layer listeners to IPv6 \
+            addresses to forward frames to, defaults to None
+    :type listeners: dictionary with keys of String IPv6 addresses and values \
+            are upper layer listeners
+    """
     def __init__(self, ips, listeners=None):
         """
         Constructor for IPv6_listener
-        :param ips: - list of ips to listen for
-        :param listeners: default of None, dictionary mapping list of upper
-        layer listeners to IPv6 addresses to forward frames to
         """
         for ip in ips:
             print(ip)
@@ -26,6 +32,11 @@ class IPv6_Listener():
         self.listeners = listeners
 
     def listen(self, queue):
+        """
+        Listen for frames coming in on queue to parse the IPv6 objects inside
+        :param queue: Queue to listen in on
+        :type queue: Queue object
+        """
         while True:
             frame = queue.get()
             frame.payload = IPv6.ipv6_parser(frame.payload, recursive=False)
