@@ -1,8 +1,9 @@
-# Provide object of EthernetII protocol
+"""Creates Etherframe object and provides methods to parse bytes to Etherframe 
+create bytes to EtherFrame object"""
 __author__ = "Matt Baker"
 __credits__ = ["Matt Baker"]
 __license__ = "GPL"
-__version__ = "1.0.5"
+__version__ = "1.0.6"
 __maintainer__ = "Matt Baker"
 __email__ = "mbakervtech@gmail.com"
 __status__ = "Development"
@@ -16,19 +17,19 @@ class EtherFrame:
     Holds all data of Etherframe
 
 
-    :param dst: string of destination MAC address
-           ex: "AB:CD:EF:01:23:45"
-    :param src: string of source MAC Address
-           ex: "AB:CD:EF:01:23:45"
-    :param payload: ARP object, IPv4 object, or object by which str.encode(payload) can be called
-    :param ethertype: string representing ethertype. Default value is ipv4
-            Can take custom value consisting of 4 hex string asciis characters
-            ex: "8035"
-            Can take values of "ipv4", "ipv6", "arp", or "rarp" and convert them to correct ethertype code
-            Default value is "ipv4"
-    :raise ValueError if dst not valid MAC address
-    :raise ValueError if src not valid MAC address
-    :raise ValueError if ethertype is not supported builtin AND is not 2 bytes of a string of hex characters
+    :param dst: string of destination MAC address ex: "AB:CD:EF:01:23:45"
+    :type dst: String     
+    :param src: string of source MAC Address ex: "AB:CD:EF:01:23:45"
+    :type src: String
+    :param payload: data to put into Etherframe
+    :type payload: ARP, IPv4, IPv6, or any or any object str.encode(payload) can be called
+    :param ethertype: String representing ethertype - defaults to "ipv4". Can \
+        be ipv4, ipv6, arp, or rarp,  or a custom value consisting of 4 hex \
+        string ascii chars, such as "8035"
+    :type ethertype: String 
+    :raise ValueError: if dst not valid MAC address, if src not valid MAC \
+        address, or ethertype not supported builtin AND is not 2 bytes of a \
+        string of hex characters
     """
 
     # For ethertype to bytes lookup, and reverse lookup
@@ -59,7 +60,8 @@ class EtherFrame:
         If self.payload is IPv4 or ARP object, their as_bytes function is called, providing the conversion of payload
         to properly formated bytes to be inserted into frame to be sent on Raw_NIC
         If self.payload is not IPv4 or ARP object, self.payload is conver
-        :return: - bytes representation of EtherFrame
+        :return: bytes representation of EtherFrame
+        :rtype: bytes
         """
         dst = addr_to_bytes(self.dst)
         src = addr_to_bytes(self.src)
@@ -87,11 +89,15 @@ class EtherFrame:
 
     def parse_further_layers(self, recursive=True):
         """
-        Method that parses higher layers
-        :param recursive - boolean value of whether parsing funciton should
-        be called recursively through all layers
+        Method that parses higher layer information contained in payload
+        :param recursive:  boolean value of whether parsing function should \
+            be called recursively through all layers
+        :type recursive: boolean
+        :return: Object representation of payload if possible to parse, if not \
+                returns self.payload
+        :rtype: ARP, IPv4, IPv6, or bytes
         """
-            # If ARP, parse ARP
+        # If ARP, parse ARP
         if self.etype == "arp":
             return ARP.arp_parser(self.payload)
         # If IPv4, parse IPv4
@@ -100,15 +106,24 @@ class EtherFrame:
         elif self.etype == "ipv6":
             return IPv6.ipv6_parser(self.payload, recursive=recursive)
         else:
-            return data[14:]
+            return self.payload
+
     @classmethod
     def etherframe_parser(cls, data, recursive=True):
         """
         Class Method that parses group of bytes to create EtherFrame Object
-        :param data: etherframe passed in as bytes
-        If IPv4 is type of frame, payload will be IPv4 object created
-        If ARP is type of frame, payload will be ARP object created
+        :param data: etherframe passed in as bytes \
+            If IPv4 is type of frame, payload will be IPv4 object created \
+            If ARP is type of frame, payload will be ARP object created
+        :type data: EtherFrame
+        :param recursive: boolean of whether to parse recursively to higher \
+            layers, defaults to True \
+        If protocol is "IPv4", payload will be IPv4 object created \
+        If protocol is "IPv6", payload will be IPv6 object created \
+        If protocol is "ARP", payload will be ARP object created \
+        :type recursive: Boolean
         :return: EtherFrame instance that contains the values that was in data
+        :rtype: EtherFrame
         """
         dst = bytes_to_MAC(data[0:6])
         src = bytes_to_MAC(data[6:12])
@@ -132,6 +147,7 @@ class EtherFrame:
         """
         Create string representation of EtherFrame
         :return: String representation of EtherFrame
+        :rtype: String
         """
         header = "*" * 20 + "_Ethernet Frame_" + "*" * 20
         source = "Source address: " + self.src.upper()
